.. :changelog:

History
-------

0.2.0 (2016-01-15)
---------------------

* Allow lowercase bases in the input fasta file.
* Do not mutate gaps or ambiguous positions.
* Add a command line switch to show the program version.

0.1.1 (2015-06-17)
---------------------

* Remove spaces from the summary file column headings.  This will simplify downstream
  analysis in some scripting languages.


0.1.0 (2015-05-21)
---------------------

* First release on GitHub, Read the Docs, and PyPI.
